"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getClickableAncestor = exports.isClickable = exports.isVisible = exports.canTargetValue = void 0;
const serialize_1 = require("./serialize");
exports.canTargetValue = (element) => {
    // do not target value of inputs where the value will change
    const tagName = element.tagName.toLowerCase();
    if (tagName === 'input') {
        return ['checkbox', 'radio'].includes(element.type);
    }
    return tagName !== 'textarea';
};
exports.isVisible = (element, computedStyle) => {
    const htmlElement = element;
    if (htmlElement.offsetWidth <= 0 || htmlElement.offsetHeight <= 0) {
        return false;
    }
    if (computedStyle && computedStyle.visibility === 'hidden') {
        return false;
    }
    if (computedStyle && computedStyle.display === 'none') {
        return false;
    }
    return true;
};
exports.isClickable = (element, computedStyle) => {
    // assume it is clickable if the cursor is a pointer
    const clickable = computedStyle.cursor === 'pointer';
    return clickable && exports.isVisible(element, computedStyle);
};
exports.getClickableAncestor = (element) => {
    /**
     * Crawl up until we reach the top "clickable" ancestor.
     * If the target is the descendant of "a"/"button"/"input" or a clickable element choose it.
     * Otherwise choose the original element as the target.
     */
    let ancestor = element;
    console.debug('qawolf: get clickable ancestor for', serialize_1.getXpath(element));
    while (ancestor.parentElement) {
        if (['a', 'button', 'input'].includes(ancestor.tagName.toLowerCase())) {
            // stop crawling when the ancestor is a good clickable tag
            console.debug(`qawolf: found clickable ancestor: ${ancestor.tagName}`, serialize_1.getXpath(ancestor));
            return ancestor;
        }
        if (!exports.isClickable(ancestor.parentElement, window.getComputedStyle(ancestor.parentElement))) {
            // stop crawling at the first non-clickable element
            console.debug('qawolf: found clickable ancestor', serialize_1.getXpath(ancestor));
            return ancestor;
        }
        ancestor = ancestor.parentElement;
    }
    // stop crawling at the root
    console.debug('qawolf: found clickable ancestor', serialize_1.getXpath(ancestor));
    return ancestor;
};
//# sourceMappingURL=element.js.map